<a id="librelingo_yaml_loader.yaml_loader"></a>

# librelingo\_yaml\_loader.yaml\_loader

<a id="librelingo_yaml_loader.yaml_loader.load_course"></a>

#### load\_course

```python
def load_course(path: str)
```

Load a YAML-based course into a Course() object

